@@ -11,6 +11,7 @@ from zigzag.classes.hardware.architecture.dimension import Dimension
 from zigzag.classes.hardware.architecture.memory_hierarchy import MemoryHierarchy
 from zigzag.classes.hardware.architecture.operational_array import OperationalArray
 from zigzag.classes.mapping.spatial.spatial_mapping import SpatialMapping
+from zigzag.classes.opt.spatial.generator import UserSpatialMappingGenerator
 from zigzag.classes.stages.Stage import Stage
 from zigzag.classes.stages.SpatialMappingConversionStage import SpatialMappingConversionStage
 from zigzag.classes.workload.layer_node import LayerNode
@@ -52,8 +53,8 @@ class SpatialMappingGeneratorStage(Stage):
         :return: True if layer is set correctly
         """
         if layer is None:
-            return False
-        if not layer.core_allocation:
+            raise ValueError()
+        if layer.core_allocation is None:
             logger.critical(f"Layer {layer} has no core allocation.")
             raise ValueError()
         return True
@@ -70,11 +71,11 @@ class SpatialMappingGeneratorStage(Stage):
             user_spatial_mappings = user_provided_spatial_mappings
         else:  # There is no USM provided
             # Initialize the UserSpatialMappingGenerator which will automatically generate SMs
-
+            user_spatial_mapping_generator = UserSpatialMappingGenerator(self.layer, self.accelerator)
             # Get all the USMs by running the generator
-            user_spatial_mappings = list(self.generate_user_spatial_mappings())
+            user_spatial_mappings = list((usm for usm in user_spatial_mapping_generator.run()))
+            logger.debug(f"No user-provided spatial mappings found. Auto-generating..")
         nb_user_spatial_mappings = len(user_spatial_mappings)
-        logger.debug(f"Generated {nb_user_spatial_mappings} spatial mappings.")
 
         for i, user_spatial_mapping in enumerate(user_spatial_mappings):
             logger.info(f"Launching spatial mapping {i+1}/{nb_user_spatial_mappings}: {user_spatial_mapping}.")
